@@ -15,6 +15,7 @@ def init_cacheify(app, config=None):
                 'NoneType.')
 
     config = config if config else app.config
+    config.setdefault('CACHE_TYPE', 'simple')
 
     # Look for MemCachier.
     if any([k.startswith('MEMCACHIER_') for k in environ]):
@@ -26,4 +27,9 @@ def init_cacheify(app, config=None):
         config.setdefault('CACHE_MEMCACHED_PASSWORD',
                 environ.get('MEMCACHIER_PASSWORD'))
 
+    # Look for RedisGreen.
+    if any([k.startswith('REDISGREEN_') for k in environ]):
+        config.setdefault('CACHE_TYPE', 'redis')
+        config.setdefault('CACHE_REDIS_URL', environ.get('REDISGREEN_URL'))
+
     return Cache(app, config)
